@@ -320,6 +320,8 @@ sub delete_transaction {
   
   my $table = "ap";
   $table = "gl" if $form->{batch} eq 'gl';
+
+  $form->{id} *= 1;
   
   $query = qq|SELECT amount
               FROM $table
@@ -364,7 +366,9 @@ sub delete_payment_reversal {
   # connect to database
   my $dbh = $form->dbconnect_noauto($myconfig);
   my $query;
- 
+
+  $form->{id} *= 1;
+  
   $query = qq|SELECT ac.trans_id, ac.amount * -1
               FROM acc_trans ac
 	      JOIN vr ON (vr.id = ac.vr_id)
@@ -417,7 +421,9 @@ sub delete_batch {
 
   # connect to database
   my $dbh = $form->dbconnect_noauto($myconfig);
-  
+
+  $form->{batchid} *= 1;
+    
   my $query = qq|SELECT vr.id, vr.trans_id
                  FROM vr
 	         WHERE vr.br_id = $form->{batchid}|;
@@ -517,13 +523,16 @@ sub delete_batch {
 sub post_batch {
   my ($self, $myconfig, $form, $dbh) = @_;
 
-  my $disconnect = ($dbh) ? 0 : 1;
+  my $disconnect;
   
   # connect to database
   if (! $dbh) {
     $dbh = $form->dbconnect_noauto($myconfig);
+    $disconnect = 1;
   }
 
+  $form->{batchid} *= 1;
+  
   my $query = qq|SELECT trans_id, id
                  FROM vr
 	         WHERE br_id = $form->{batchid}|;
@@ -629,7 +638,7 @@ sub payment_reversal {
   my $description;
   my $translation;
 
-  if ($form->{id}) {
+  if ($form->{id} *= 1) {
     # get payment account and vouchernumber
     $query = qq|SELECT ac.source, ac.memo, c.accno, c.description,
                 l.description
@@ -660,7 +669,9 @@ sub post_payment_reversal {
   
   $form->{vouchernumber} = $form->update_defaults($myconfig, 'vouchernumber', $dbh) unless $form->{vouchernumber};
   
-  if ($form->{id}) {
+  $form->{batchid} *= 1;
+  
+  if ($form->{id} *= 1) {
 
     $query = qq|SELECT ac.amount
 		FROM acc_trans ac
