@@ -1,24 +1,10 @@
 #=====================================================================
-# SQL-Ledger Accounting
-# Copyright (c) 2002
+# SQL-Ledger ERP
+# Copyright (c) 2006
 #
-#  Author: Dieter Simader
-#   Email: dsimader@sql-ledger.org
-#     Web: http://www.sql-ledger.org
+#  Author: DWS Systems Inc.
+#     Web: http://www.sql-ledger.com
 #
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #======================================================================
 #
 # setup module
@@ -35,13 +21,15 @@ use SL::User;
 $form = new Form;
 
 $locale = new Locale $language, "admin";
-  
+$form->{charset} = $locale->{charset};
+
 eval { require DBI; };
 $form->error($locale->text('DBI not installed!')) if ($@);
 
 $form->{stylesheet} = "sql-ledger.css";
 $form->{favicon} = "favicon.ico";
 $form->{timeout} = 600;
+$form->{"root login"} = 1;
 
 require "$form->{path}/pw.pl";
 
@@ -54,11 +42,9 @@ if (-f "$form->{path}/custom_$form->{script}") {
 
 if ($form->{action}) {
 
-  $subroutine = $locale->findsub($form->{action});
-
   &check_password unless $form->{action} eq 'logout';
   
-  &$subroutine;
+  &{ $locale->findsub($form->{action}) };
     
 } else {
 
@@ -95,7 +81,7 @@ sub adminlogin {
 <script language="JavaScript" type="text/javascript">
 <!--
 function sf(){
-  document.admin.password.focus();
+  document.forms[0].password.focus();
 }
 // End -->
 </script>
@@ -104,10 +90,10 @@ function sf(){
 
 <div align=center>
 
-<a href="http://www.sql-ledger.org"><img src=sql-ledger.png border=0>&trade;</a>
+<a href="http://www.sql-ledger.org"><img src=$images/sql-ledger.gif border=0 target=_blank></a>
 <h1 class=login>|.$locale->text('Version').qq| $form->{version}<p>|.$locale->text('Administration').qq|</h1>
 
-<form method=post action="$form->{script}" name=admin>
+<form method=post action="$form->{script}">
 
 <table>
   <tr>
@@ -121,7 +107,7 @@ function sf(){
 
 </form>
 
-<a href=http://www.sql-ledger.org>SQL-Ledger |.$locale->text('website').qq|</a>
+<a href=http://www.sql-ledger.org target=_blank>SQL-Ledger |.$locale->text('website').qq|</a>
 
 </div>
 
@@ -132,8 +118,47 @@ function sf(){
 }
 
 
+sub create_config {
+
+  $form->{sessionkey} = "";
+  $form->{sessioncookie} = "";
+  
+  if ($form->{password}) {
+    my $t = time + $form->{timeout};
+    srand( time() ^ ($$ + ($$ << 15)) );
+    $key = "root login$form->{password}$t";
+
+    my $i = 0;
+    my $l = length $key;
+    my $j = $l;
+    my %ndx = ();
+    my $pos;
+
+    while ($j > 0) {
+      $pos = int rand($l);
+      next if $ndx{$pos};
+      $ndx{$pos} = 1;
+      $form->{sessioncookie} .= substr($key, $pos, 1);
+      $form->{sessionkey} .= substr("0$pos", -2);
+      $j--;
+    }
+  }
+
+  open(CONF, ">$userspath/root login.conf") or $form->error("root login.conf : $!");
+  print CONF qq|# configuration file for root login
+
+\%rootconfig = (
+sessionkey => '$form->{sessionkey}'
+);\n\n|;
+
+  close CONF;
+
+}
+
+
 sub login {
 
+  &create_config;
   &list_users;
 
 }
@@ -141,7 +166,7 @@ sub login {
 
 sub logout {
 
-  $form->{callback} = "$form->{script}?path=$form->{path}&endsession=1";
+  $form->{callback} = "$form->{script}?path=$form->{path}";
   $form->redirect($locale->text('You are logged out'));
 
 }
@@ -160,7 +185,7 @@ sub add_user {
   }
   $myconfig->{vclimit} = 1000;
   $myconfig->{menuwidth} = 155;
-  $myconfig->{timeout} = 3600;
+  $myconfig->{timeout} = 10800;
   
   &form_header;
   &form_footer;
@@ -189,10 +214,9 @@ sub form_footer {
 
   print qq|
 
-<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}">
+<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
 
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=submit class=submit name=action value="|.$locale->text('Save').qq|">
 $delete
@@ -238,6 +262,7 @@ sub list_users {
 # type=submit $locale->text('Pg Database Administration')
 # type=submit $locale->text('PgPP Database Administration')
 # type=submit $locale->text('Oracle Database Administration')
+# type=submit $locale->text('Sybase Database Administration')
 
   foreach $item (User->dbdrivers) {
     $dbdrivers .= qq|<input name=action type=submit class=submit value="|.$locale->text("$item Database Administration").qq|">|;
@@ -256,7 +281,7 @@ sub list_users {
 
   $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." ".$locale->text('Administration');
 
-  $form->{login} = "root login";
+
   $form->header;
 
   print qq|
@@ -275,14 +300,14 @@ sub list_users {
       <table width=100%>
         <tr class=listheading>|;
 
-  map { print "$column_header{$_}\n" } @column_index;
+  for (@column_index) { print "$column_header{$_}\n" }
   
   print qq|
         </tr>
 |;
 
 foreach $key (sort keys %member) {
-  $href = "$script?action=edit&login=$key&path=$form->{path}&sessionid=$form->{sessionid}";
+  $href = "$script?action=edit&login=$key&path=$form->{path}";
   $href =~ s/ /%20/g;
   
   $member{$key}{templates} =~ s/^$templates\///;
@@ -301,7 +326,7 @@ foreach $key (sort keys %member) {
   print qq|
         <tr class=listrow$i>|;
 
-  map { print "$column_data{$_}\n" } @column_index;
+  for (@column_index) { print "$column_data{$_}\n" }
 
   print qq|
         </tr>|;
@@ -318,7 +343,6 @@ print qq|
 </table>
 
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <br><input type=submit class=submit name=action value="|.$locale->text('Add User').qq|">
 <input type=submit class=submit name=action value="|.$locale->text('Change Admin Password').qq|">
@@ -349,8 +373,7 @@ sub form_header {
     # get user
     $myconfig = new User "$memberfile", "$form->{login}";
 
-    $myconfig->{signature} =~ s/\\n/\r\n/g;
-    $myconfig->{address} =~ s/\\n/\r\n/g;
+    $myconfig->{signature} =~ s/\\n/\n/g;
 
     # strip basedir from templates directory
     $myconfig->{templates} =~ s/^$templates\///;
@@ -358,22 +381,15 @@ sub form_header {
     $myconfig->{dbpasswd} = unpack 'u', $myconfig->{dbpasswd};
   }
 
-  foreach $item (qw(mm-dd-yy mm/dd/yy dd-mm-yy dd/mm/yy dd.mm.yy yyyy-mm-dd)) {
-    $dateformat .= ($item eq $myconfig->{dateformat}) ? "<option selected>$item\n" : "<option>$item\n";
-  }
-
-  foreach $item (qw(1,000.00 1000.00 1.000,00 1000,00 1'000.00)) {
-    $numberformat .= ($item eq $myconfig->{numberformat}) ? "<option selected>$item\n" : "<option>$item\n";
-  }
+  for (qw(mm-dd-yy mm/dd/yy dd-mm-yy dd/mm/yy dd.mm.yy yyyy-mm-dd)) { $selectdateformat .= "$_\n" }
 
+  for (qw(1,000.00 1000.00 1.000,00 1000,00 1'000.00)) { $selectnumberformat .= "$_\n" }
 
   %countrycodes = User->country_codes;
-  $countrycodes = "";
+  $selectcountrycodes = "";
   
-  foreach $key (sort { $countrycodes{$a} cmp $countrycodes{$b} } keys %countrycodes) {
-    $countrycodes .= ($myconfig->{countrycode} eq $key) ? "<option selected value=$key>$countrycodes{$key}" : "<option value=$key>$countrycodes{$key}";
-  }
-  $countrycodes = qq|<option value="">English\n$countrycodes|;
+  for (sort { $countrycodes{$a} cmp $countrycodes{$b} } keys %countrycodes) { $selectcountrycodes .= "${_}--$countrycodes{$_}" }
+  $selectcountrycodes = qq|--English\n$selectcountrycodes|;
 
   # is there a templates basedir
   if (! -d "$templates") {
@@ -385,29 +401,29 @@ sub form_header {
   closedir TEMPLATEDIR;
 
   @allhtml = sort grep /\.html/, @all;
-  @alldir = grep !/\.(html|tex|txt)$/, @all;
+
+  @alldir = ();
+  for (@all) {
+    if (-d "$templates/$_") {
+      push @alldir, $_;
+    }
+  }
   
   @allhtml = reverse grep !/Default/, @allhtml;
   push @allhtml, 'Default';
   @allhtml = reverse @allhtml;
   
-  foreach $item (sort @alldir) {
-    if ($item eq $myconfig->{templates}) {
-      $usetemplates .= qq|<option selected>$item\n|;
-    } else {
-      $usetemplates .= qq|<option>$item\n|;
-    }
-  }
+  for (sort @alldir) { $selectusetemplates .= qq|$_\n| }
   
   $lastitem = $allhtml[0];
   $lastitem =~ s/-.*//g;
-  $mastertemplates = qq|<option>$lastitem\n|;
-  foreach $item (@allhtml) {
-    $item =~ s/-.*//g;
+  $selectmastertemplates = qq|$lastitem\n|;
+  for (@allhtml) {
+    $_ =~ s/-.*//g;
     
-    if ($item ne $lastitem) {
-      $mastertemplates .= qq|<option>$item\n|;
-      $lastitem = $item;
+    if ($_ ne $lastitem) {
+      $selectmastertemplates .= qq|$_\n|;
+      $lastitem = $_;
     }
   }
 
@@ -415,38 +431,23 @@ sub form_header {
   @all = grep /.*\.css$/, readdir CSS;
   closedir CSS;
   
-  foreach $item (@all) {
-    if ($item eq $myconfig->{stylesheet}) {
-      $selectstylesheet .= qq|<option selected>$item\n|;
-    } else {
-      $selectstylesheet .= qq|<option>$item\n|;
-    }
-  }
-  $selectstylesheet .= "<option>\n";
+  $selectstylesheet = "\n";
+  for (sort @all) { $selectstylesheet .= qq|$_\n| }
   
   if (%printer && $latex) {
-    $selectprinter = "<option>\n";
-    foreach $item (sort keys %printer) {
-      if ($myconfig->{printer} eq $item) {
-	$selectprinter .= qq|<option value="$item" selected>$item\n|;
-      } else {
-	$selectprinter .= qq|<option value="$item">$item\n|;
-      }
-    }
+    $selectprinter = "\n";
+    for (sort keys %printer) { $selectprinter .= "$_\n" }
 
     $printer = qq|
 	<tr>
 	  <th align=right>|.$locale->text('Printer').qq|</th>
-	  <td><select name=printer>$selectprinter</select></td>
+	  <td><select name=printer>|.$form->select_option($selectprinter, $myconfig->{printer}).qq|</td>
 	</tr>
 |;
 
   }
   
-  $user = $form->{login};
-  $form->{login} = "root login";
   $form->header;
-  $form->{login} = $user;
  
   print qq|
 <body class=admin>
@@ -470,7 +471,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Name').qq|</th>
-	  <td><input name=name size=15 value="$myconfig->{name}"></td>
+	  <td><input name=name size=15 value="|.$form->quote($myconfig->{name}).qq|"></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('E-mail').qq|</th>
@@ -490,11 +491,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Company').qq|</th>
-	  <td><input name=company size=35 value="$myconfig->{company}"></td>
-	</tr>
-	<tr valign=top>
-	  <th align=right>|.$locale->text('Address').qq|</th>
-	  <td><textarea name=address rows=4 cols=35>$myconfig->{address}</textarea></td>
+	  <td><input name=company size=35 value="|.$form->quote($myconfig->{company}).qq|"></td>
 	</tr>
       </table>
     </td>
@@ -502,11 +499,11 @@ sub form_header {
       <table>
 	<tr>
 	  <th align=right>|.$locale->text('Date Format').qq|</th>
-	  <td><select name=dateformat>$dateformat</select></td>
+	  <td><select name=dateformat>|.$form->select_option($selectdateformat, $myconfig->{dateformat}).qq|</select></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Number Format').qq|</th>
-	  <td><select name=numberformat>$numberformat</select></td>
+	  <td><select name=numberformat>|.$form->select_option($selectnumberformat, $myconfig->{numberformat}).qq|</select></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Dropdown Limit').qq|</th>
@@ -518,11 +515,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Language').qq|</th>
-	  <td><select name=countrycode>$countrycodes</select></td>
-	</tr>
-	<tr>
-	  <th align=right>|.$locale->text('Character Set').qq|</th>
-	  <td><input name=charset value="$myconfig->{charset}"></td>
+	  <td><select name=countrycode>|.$form->select_option($selectcountrycodes, $myconfig->{countrycode}, undef, 1).qq|</td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Session Timeout').qq|</th>
@@ -531,12 +524,12 @@ sub form_header {
 
 	<tr>
 	  <th align=right>|.$locale->text('Stylesheet').qq|</th>
-	  <td><select name=userstylesheet>$selectstylesheet</select></td>
+	  <td><select name=userstylesheet>|.$form->select_option($selectstylesheet, $myconfig->{stylesheet}).qq|</select></td>
 	</tr>
 	$printer
 	<tr>
 	  <th align=right>|.$locale->text('Use Templates').qq|</th>
-	  <td><select name=usetemplates>$usetemplates</select></td>
+	  <td><select name=usetemplates>|.$form->select_option($selectusetemplates, $myconfig->{templates}).qq|</select></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('New Templates').qq|</th>
@@ -544,7 +537,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Setup Templates').qq|</th>
-	  <td><select name=mastertemplates>$mastertemplates</select></td>
+	  <td><select name=mastertemplates>|.$form->select_option($selectmastertemplates, $myconfig->{templates}).qq|</select></td>
 	</tr>
 	<input type=hidden name=templates value=$myconfig->{templates}>
       </table>
@@ -565,7 +558,7 @@ sub form_header {
 
     $checked = "";
     if ($myconfig->{dbdriver} eq $item) {
-      map { $form->{"${item}_$_"} = $myconfig->{$_} } qw(dbhost dbport dbuser dbpasswd dbname sid);
+      for (qw(dbhost dbport dbuser dbpasswd dbname sid)) { $form->{"${item}_$_"} = $myconfig->{$_} }
       $checked = "checked";
     }
 
@@ -577,7 +570,7 @@ sub form_header {
 	</tr>
 	<tr>|;
 
-    if ($item =~ /Pg/) {
+    if ($item =~ /(Pg|Sybase)/) {
       print qq|
 	  <th align=right>|.$locale->text('Dataset').qq|</th>
 	  <td><input name="${item}_dbname" size=15 value=$form->{"${item}_dbname"}></td>
@@ -655,21 +648,20 @@ sub form_header {
   
   %role = ( 'admin' => $locale->text('Administrator'),
             'user' => $locale->text('User'),
+            'supervisor' => $locale->text('Supervisor'),
 	    'manager' => $locale->text('Manager')
 
 	   );
 	    
   $selectrole = "";
-  foreach $item (qw(user admin manager)) {
-    $selectrole .= ($myconfig->{role} eq $item) ? "<option selected value=$item>$role{$item}\n" : "<option value=$item>$role{$item}\n";
-  }
+  for (qw(user admin supervisor manager)) { $selectrole .= "$_--$role{$_}\n" }
   
   print qq|
   <tr class=listheading>
     <th colspan=2>|.$locale->text('Access Control').qq|</th>
   </tr>
   <tr>
-    <td><select name=role>$selectrole</select></td>
+    <td><select name=role>|.$form->select_option($selectrole, $myconfig->{role}, undef, 1).qq|</select></td>
   </tr>
 |;
   
@@ -685,20 +677,20 @@ sub form_header {
       $checked = ($excl{$key}{$key}) ? "" : "checked";
     }
     
-    # can't have variable names with spaces
-    # the 1 is for apache 2
-    $item = $form->escape("${key}--$key", 1);
-    
+    # can't have variable names with & and spaces
+    $item = $form->escape("${key}--$key",1);
+
     $acsheading = $key;
     $acsheading =~ s/ /&nbsp;/g;
-    
+
     $acsheading = qq|
-    <th align=left><input name="$item" class=checkbox type=checkbox value=1 $checked>&nbsp;$acsheading</th>\n|;
+    <th align=left nowrap><input name="$item" class=checkbox type=checkbox value=1 $checked>&nbsp;$acsheading</th>\n|;
     $menuitems .= "$item;";
     $acsdata = "
     <td>";
 
     foreach $item (@{ $acs{$key} }) {
+
       next if ($key eq $item);
 
       $checked = "checked";
@@ -706,8 +698,8 @@ sub form_header {
 	$checked = ($excl{$key}{$item}) ? "" : "checked";
       }
 
-      $acsitem = $form->escape("${key}--$item", 1);
-      
+      $acsitem = $form->escape("${key}--$item",1);
+
       $acsdata .= qq|
     <br><input name="$acsitem" class=checkbox type=checkbox value=1 $checked>&nbsp;$item|;
       $menuitems .= "$acsitem;";
@@ -738,11 +730,17 @@ sub save {
 
   # no driver checked
   $form->error($locale->text('Database Driver not checked!')) unless $form->{dbdriver};
-
-  # no spaces allowed in login name
-  ($form->{login}) = split / /, $form->{login};
-
+  
   $form->isblank("login", $locale->text('Login name missing!'));
+ 
+  # no spaces or strange characters allowed in login name
+  $form->error($locale->text('No space allowed for login!')) if $form->{login} =~ / /;
+  if ($form->{login} =~ /\W/) {
+    $login = $form->{login};
+    $login =~ s/\@//;
+    
+    $form->error($locale->text('login may only contain alphanumeric characters!')) if $login =~ /\W/;
+  }
   
   # check for duplicates
   if (!$form->{edit}) {
@@ -754,8 +752,7 @@ sub save {
   }
   
   # no spaces allowed in directories
-  ($form->{newtemplates}) = split / /, $form->{newtemplates};
-  $form->{newtemplates} =~ s/(\.\.|\*)//g;
+  $form->{newtemplates} =~ s/( |\.\.|\*)//g;
   
   if ($form->{newtemplates} ne "") {
     $form->{templates} = $form->{newtemplates};
@@ -779,14 +776,13 @@ sub save {
 
   $form->{acs} = "";
   foreach $item (@acs) {
-    $item = $form->escape($item, 1);
-
+    $item = $form->escape($item,1);
     if (!$form->{$item}) {
-      $form->{acs} .= $form->unescape($form->unescape($item)).";";
+      $form->{acs} .= $form->unescape($form->unescape("$item")).";";
     }
     delete $form->{$item};
   }
-  
+
   # check which database was filled in
   
   $form->{dbhost} = $form->{"$form->{dbdriver}_dbhost"};
@@ -794,7 +790,7 @@ sub save {
   $form->{dbpasswd} = $form->{"$form->{dbdriver}_dbpasswd"};
   $form->{dbuser} = $form->{"$form->{dbdriver}_dbuser"};
   $form->{dbname} = $form->{"$form->{dbdriver}_dbname"};
- 
+
   if ($form->{dbdriver} eq 'Oracle') {
     $form->{sid} = $form->{Oracle_sid}, ;
 
@@ -802,16 +798,18 @@ sub save {
     $form->isblank("dbport", $locale->text('Port missing!'));
     $form->isblank("dbuser", $locale->text('Dataset missing!'));
   }
-  if ($form->{dbdriver} =~ /Pg/) {
+  if ($form->{dbdriver} =~ /(Pg|Sybase)/) {
     $form->isblank("dbname", $locale->text('Dataset missing!'));
     $form->isblank("dbuser", $locale->text('Database User missing!'));
   }
     
-  foreach $item (keys %{$form}) {
-    $myconfig->{$item} = $form->{$item};
+  for (keys %{$form}) {
+    $myconfig->{$_} = $form->{$_};
   }
 
-  $myconfig->{password} = $form->{new_password} if $form->{new_password} ne $form->{old_password};
+  $myconfig->{encrypted} = $form->{new_password} eq $form->{old_password};
+  $myconfig->{password} = $form->{new_password};
+
   $myconfig->{timeout} = $form->{newtimeout};
 
   delete $myconfig->{stylesheet};
@@ -819,12 +817,14 @@ sub save {
     $myconfig->{stylesheet} = $form->{userstylesheet};
   }
   
-  $myconfig->{root} = 1;
-
+  $myconfig->{packpw} = 1;
+  delete $myconfig->{"root login"};
+  
   $myconfig->save_member($memberfile, $userspath);
 
   # create user template directory and copy master files
   if (! -d "$form->{templates}") {
+    
     umask(002);
     
     if (mkdir "$form->{templates}", oct("771")) {
@@ -833,7 +833,7 @@ sub save {
       
       # copy templates to the directory
       opendir TEMPLATEDIR, "$templates/." or $form->error("$templates : $!");
-      @templates = grep /$form->{mastertemplates}.*?\.(html|tex|txt)$/, readdir TEMPLATEDIR;
+      @templates = grep /$form->{mastertemplates}-/, readdir TEMPLATEDIR;
       closedir TEMPLATEDIR;
 
       foreach $file (@templates) {
@@ -863,6 +863,7 @@ sub delete {
   $form->{templates} = ($form->{templates}) ? "$templates/$form->{templates}" : "$templates/$form->{login}";
   
   $form->error("$memberfile ".$locale->text('locked!')) if (-f ${memberfile}.LCK);
+
   open(FH, ">${memberfile}.LCK") or $form->error("${memberfile}.LCK : $!");
   close(FH);
   
@@ -943,14 +944,16 @@ sub delete {
     }
   }
 
-  if ($myconfig{login}) {
-    map { $form->{$_} = $myconfig{$_} } keys %myconfig;
-    User::delete_login("", \%$form);
+  if ($myconfig{dbconnect}) {
+    $myconfig{dbpasswd} = unpack 'u', $myconfig{dbpasswd};
+    for (keys %myconfig) { $form->{$_} = $myconfig{$_} }
+
+    User->delete_login(\%$form);
   
     # delete config file for user
     unlink "$userspath/$form->{login}.conf";
   }
-  
+
   $form->redirect($locale->text('User deleted!'));
   
 }
@@ -965,28 +968,10 @@ sub login_name {
 }
 
 
-
-sub get_value {
-  my $line = shift;
-  
-  my ($null, $value) = split /=/, $line, 2;
-
-  # remove comments
-  $value =~ s/^\s*#.*//g;
-      
-  # remove any trailing whitespace
-  $value =~ s/^\s*(.*?)\s*$/$1/;
-
-  $value;
-}
-
-
-
 sub change_admin_password {
 
   $form->{title} = qq|SQL-Ledger |.$locale->text('Accounting')." ".$locale->text('Administration')." / ".$locale->text('Change Admin Password');
 
-  $form->{login} = "root login";
   $form->header;
 
   print qq|
@@ -1020,7 +1005,6 @@ sub change_admin_password {
 <br>
 <hr size=3 noshade>
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <p>
 <input type=submit class=submit name=action value="|.$locale->text('Change Password').qq|">
@@ -1041,9 +1025,13 @@ sub change_password {
   $root->{password} = $form->{new_password};
   
   $root->{'root login'} = 1;
+  $root->{login} = "root login";
   $root->save_member($memberfile);
 
-  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}";
+  $form->{password} = $form->{new_password};
+  &create_config;
+  
+  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&password=$form->{password}";
 
   $form->redirect($locale->text('Password changed!'));
 
@@ -1054,23 +1042,67 @@ sub check_password {
 
   $root = new User "$memberfile", "root login";
 
+  $rootname = "root login";
+  eval { require "$userspath/${rootname}.conf"; };
+  
   if ($root->{password}) {
       
     if ($form->{password}) {
       $form->{callback} .= "&password=$form->{password}" if $form->{callback};
-      $form->{sessionid} = time;
       if ($root->{password} ne crypt $form->{password}, 'ro') {
 	&getpassword;
 	exit;
       }
+
+      # create config
+      &create_config;
+      
     } else {
+      
       if ($ENV{HTTP_USER_AGENT}) {
 	$ENV{HTTP_COOKIE} =~ s/;\s*/;/g;
-	%cookie = split /[=;]/, $ENV{HTTP_COOKIE};
-	if ((! $cookie{"SQL-Ledger-root login"}) || $cookie{"SQL-Ledger-root login"} ne $form->{sessionid}) {
+	@cookies = split /;/, $ENV{HTTP_COOKIE};
+	%cookie = ();
+	foreach (@cookies) {
+	  ($name,$value) = split /=/, $_, 2;
+	  $cookie{$name} = $value;
+	}
+	
+	$cookie = ($form->{path} eq 'bin/lynx') ? $cookie{login} : $cookie{"SL-root login"};
+
+        if ($cookie) {
+	  $form->{sessioncookie} = $cookie;
+
+	  $s = "";
+	  %ndx = ();
+	  $l = length $form->{sessioncookie};
+
+	  for $i (0 .. $l - 1) {
+	    $j = substr($rootconfig{sessionkey}, $i * 2, 2);
+	    $ndx{$j} = substr($cookie, $i, 1);
+	  }
+
+	  for (sort keys %ndx) {
+	    $s .= $ndx{$_};
+	  }
+
+	  $l = length 'root login';
+	  $login = substr($s, 0, $l);
+	  $time = substr($s, -10);
+	  $password = substr($s, $l, (length $s) - ($l + 10));
+	  
+	  if ((time > $time) || ($login ne 'root login') || ($root->{password} ne crypt $password, 'ro')) {
+	    &getpassword;
+	    exit;
+	  }
+
+	} else {
 	  &getpassword;
 	  exit;
 	}
+      } else {
+	&getpassword;
+	exit;
       }
     }
   }
@@ -1102,6 +1134,14 @@ sub oracle_database_administration {
 }
 
 
+sub sybase_database_administration {
+  
+  $form->{dbdriver} = 'Sybase';
+  &dbselect_source;
+
+}
+
+
 sub dbdriver_defaults {
 
   # load some defaults for the selected driver
@@ -1116,13 +1156,19 @@ sub dbdriver_defaults {
 		             dbdefault => $sid,
 				dbhost => `hostname`,
 			 connectstring => 'SID'
+			      },
+                   'Sybase' => { dbport => '',
+		                dbuser => 'sql-ledger',
+		             dbdefault => '',
+				dbhost => '',
+			 connectstring => $locale->text('Connect to')
 			      }
                     );
 
   $driverdefaults{PgPP} = $driverdefaults{Pg};
 
-  map { $form->{$_} = $driverdefaults{$form->{dbdriver}}{$_} } keys %{ $driverdefaults{Pg} };
-  
+  for (keys %{ $driverdefaults{Pg} }) { $form->{$_} = $driverdefaults{$form->{dbdriver}}{$_} }
+
 }
   
 
@@ -1130,14 +1176,8 @@ sub dbselect_source {
 
   &dbdriver_defaults;
 
-  $msg{Pg} = $locale->text('Leave host and port field empty unless you want to make a remote connection.');
-  $msg{PgPP} = $msg{Pg};
-  $msg{Oracle} = $locale->text('You must enter a host and port for local and remote connections!');
-  
-
  $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." / ".$locale->text('Database Administration');
   
-  $form->{login} = "root login";
   $form->header;
 
   print qq|
@@ -1184,7 +1224,6 @@ sub dbselect_source {
 
 <input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <br>
 
@@ -1201,9 +1240,6 @@ sub dbselect_source {
 <p>|.$locale->text('This is a preliminary check for existing sources. Nothing will be created or deleted at this stage!')
 
 .qq|
-<br>$msg{$form->{dbdriver}}
-
-
 </body>
 </html>
 |;
@@ -1224,7 +1260,6 @@ sub update_dataset {
 
   $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." ".$locale->text('Database Administration')." / ".$locale->text('Update Dataset');
   
-  $form->{login} = "root login";
   $form->header;
 
   print qq|
@@ -1238,7 +1273,7 @@ sub update_dataset {
 
   foreach $key (sort keys %needsupdate) {
     if ($needsupdate{$key} ne $form->{dbversion}) {
-      $upd .= qq|<input name="db$key" type=checkbox value=1 checked> $key\n|;
+      $upd .= qq|<input name="db$key" class=checkbox type=checkbox value=1 checked> $key\n|;
       $form->{dbupdate} .= "db$key ";
     }
   }
@@ -1251,14 +1286,13 @@ sub update_dataset {
     print qq|
 <table width=100%>
 <form method=post action=$form->{script}>
+|;
 
-<input type=hidden name=dbdriver value=$form->{dbdriver}>
-<input type=hidden name=dbhost value=$form->{dbhost}>
-<input type=hidden name=dbport value=$form->{dbport}>
-<input type=hidden name=dbuser value=$form->{dbuser}>
-<input type=hidden name=dbpasswd value=$form->{dbpasswd}>
-<input type=hidden name=dbdefault value=$form->{dbdefault}>
+    $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}";
+    $form->{nextsub} = "dbupdate";
+    $form->hide_form(qw(dbdriver dbhost dbport dbuser dbpasswd dbdefault dbupdate mextsub callback path));
 
+    print qq|
 <tr class=listheading>
   <th>|.$locale->text('The following Datasets need to be updated').qq|</th>
 </tr>
@@ -1272,19 +1306,11 @@ $upd
 <tr>
 <td>
 
-<input name=dbupdate type=hidden value="$form->{dbupdate}">
-
-<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
-
-<input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
-
-<input type=hidden name=nextsub value=dbupdate>
-
 <hr size=3 noshade>
 
 <br>
 <input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 
 </td></tr>
 </table>
@@ -1293,7 +1319,7 @@ $upd
 
   } else {
 
-    print $locale->text('All Datasets up to date!');
+    print $locale->text('DBA')." : $form->{dbuser} : " .$locale->text('All Datasets up to date!');
 
   }
   
@@ -1330,15 +1356,15 @@ sub create_dataset {
   # add Default at beginning
   unshift @charts, qq|<input name=chart class=radio type=radio value="Default" checked>Default|;
 
-  $selectencoding = qq|<option>
+  $selectencoding{Pg} = qq|<option>
   <option value=SQL_ASCII>ASCII
-  <option value=EUC_JP>Japanese EUC
+  <option value=UTF8>Unicode (UTF-8)
   <option value=EUC_CN>Chinese EUC
+  <option value=EUC_JP>Japanese EUC
   <option value=EUC_KR>Korean EUC
-  <option value=JOHAB>Korean EUC (Hangle base)
+  <option value=JOHAB>Korean (Hangul)
   <option value=EUC_TW>Taiwan EUC
-  <option value=UNICODE>Unicode (UTF-8)
-  <option value=MULE_INTERNAL>Mule internal type
+  <option value=KOI8>KOI8-R(U)
   <option value=LATIN1>ISO 8859-1/ECMA 94 (Latin alphabet no. 1)
   <option value=LATIN2>ISO 8859-2/ECMA 94 (Latin alphabet no. 2)
   <option value=LATIN3>ISO 8859-3/ECMA 94 (Latin alphabet no. 3)
@@ -1353,9 +1379,11 @@ sub create_dataset {
   <option value=ISO_8859_6>ISO 8859-6/ECMA 114 (Latin/Arabic)
   <option value=ISO_8859_7>ISO 8859-7/ECMA 118 (Latin/Greek)
   <option value=ISO_8859_8>ISO 8859-8/ECMA 121 (Latin/Hebrew)
-  <option value=KOI8>KOI8-R(U)
-  <option value=WIN>Windows CP1251
-  <option value=ALT>Windows CP866
+  <option value=MULE_INTERNAL>Mule internal type
+  <option value=ALT>Windows CP866 (Cyrillic)
+  <option value=WIN1250>Windows CP1250 (Central Euope)
+  <option value=WIN>Windows CP1251 (Cyrillic)
+  <option value=WIN1252>Windows CP1252 (Western European)
   <option value=WIN1256>Windows CP1256 (Arabic)
   <option value=TCVN>Windows CP1258 (Vietnamese)
   <option value=WIN874>Windows CP874 (Thai)
@@ -1363,7 +1391,6 @@ sub create_dataset {
   
   $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." ".$locale->text('Database Administration')." / ".$locale->text('Create Dataset');
   
-  $form->{login} = "root login";
   $form->header;
 
   print qq|
@@ -1386,7 +1413,7 @@ sub create_dataset {
     <td>
 |;
 
-    map { print "[&nbsp;$_&nbsp;] " } @dbsources;
+    for (@dbsources) { print "[&nbsp;$_&nbsp;] " }
     
     print qq|
     </td>
@@ -1398,13 +1425,20 @@ sub create_dataset {
     <td><input name=db></td>
 
   </tr>
+|;
 
+  if ($selectencoding{$form->{dbdriver}}) {
+    print qq|
   <tr>
 
     <th align=right nowrap>|.$locale->text('Multibyte Encoding').qq|</th>
-    <td><select name=encoding>$selectencoding</select></td>
+    <td><select name=encoding>$selectencoding{$form->{dbdriver}}</select></td>
 
   </tr>
+|;
+  }
+
+  print qq|
  
   <tr>
 
@@ -1418,7 +1452,7 @@ sub create_dataset {
         <tr>
 |;
 
-    map { print "<td>$charts[$_]</td>\n" } (0 .. 2);
+    for (0 .. 2) { print "<td>$charts[$_]</td>\n" }
 
     print qq|
         </tr>
@@ -1437,23 +1471,18 @@ sub create_dataset {
     </td>
   </tr>
 </table>
- 
-<input type=hidden name=dbdriver value=$form->{dbdriver}>
-<input type=hidden name=dbuser value=$form->{dbuser}>
-<input type=hidden name=dbhost value=$form->{dbhost}>
-<input type=hidden name=dbport value=$form->{dbport}>
-<input type=hidden name=dbpasswd value=$form->{dbpasswd}>
-<input type=hidden name=dbdefault value=$form->{dbdefault}>
+|;
 
+  $form->hide_form(qw(dbdriver dbuser dbhost dbport dbpasswd dbdefault path));
+  
+  print qq|
+  
 <input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
-
-<input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
-
 <input type=hidden name=nextsub value=dbcreate>
-
+  
 <br>
 <input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 
 
 </form>
@@ -1473,7 +1502,6 @@ sub dbcreate {
   
   $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." ".$locale->text('Database Administration')." / ".$locale->text('Create Dataset');
 
-  $form->{login} = "root login";
   $form->header;
 
   print qq|
@@ -1490,11 +1518,11 @@ sub dbcreate {
 .qq|
 
 <input type=hidden name=path value="$form->{path}">
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=hidden name=nextsub value=list_users>
 
 <p><input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 </form>
 
 
@@ -1517,7 +1545,6 @@ sub delete_dataset {
 
   $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." ".$locale->text('Database Administration')." / ".$locale->text('Delete Dataset');
 
-  $form->{login} = "root login";
   $form->header;
 
   print qq|
@@ -1550,7 +1577,6 @@ sub delete_dataset {
 <input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
 
 <input type=hidden name=path value="$form->{path}">
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=hidden name=nextsub value=dbdelete>
 
@@ -1558,6 +1584,7 @@ sub delete_dataset {
 
 <br>
 <input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 
   </td></tr>
 </table>
@@ -1581,7 +1608,6 @@ sub dbdelete {
 
   $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." ".$locale->text('Database Administration')." / ".$locale->text('Delete Dataset');
 
-  $form->{login} = "root login";
   $form->header;
 
   print qq|
@@ -1598,11 +1624,11 @@ $form->{db} |.$locale->text('successfully deleted!')
 .qq|
 
 <input type=hidden name=path value="$form->{path}">
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=hidden name=nextsub value=list_users>
 
 <p><input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main').qq|">
 </form>
 
 
@@ -1617,7 +1643,7 @@ sub unlock_system {
 
   unlink "$userspath/nologin";
   
-  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}";
+  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}";
 
   $form->redirect($locale->text('Lockfile removed!'));
 
@@ -1629,10 +1655,12 @@ sub lock_system {
   open(FH, ">$userspath/nologin") or $form->error($locale->text('Cannot create Lock!'));
   close(FH);
   
-  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}";
+  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}";
 
   $form->redirect($locale->text('Lockfile created!'));
 
 }
 
 
+sub main_menu { $form->redirect }
+
