@@ -64,5 +64,15 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 --
 insert into tax (chart_id,rate) values ((select id from chart where accno = '2150'),0.05);
 --
-update defaults set inventory_accno_id = (select id from chart where accno = '1520'), income_accno_id = (select id from chart where accno = '4410'), expense_accno_id = (select id from chart where accno = '5020'), fxgain_accno_id = (select id from chart where accno = '4450'), fxloss_accno_id = (select id from chart where accno = '5810'), curr = 'USD:CAD:EUR', weightunit = 'lbs';
+INSERT INTO defaults (fldname, fldvalue) VALUES ('inventory_accno_id', (SELECT id FROM chart WHERE accno = '1520'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('income_accno_id', (SELECT id FROM chart WHERE accno = '4010'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('expense_accno_id', (SELECT id FROM chart WHERE accno = '5020'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('fxgain_accno_id', (SELECT id FROM chart WHERE accno = '4450'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('fxloss_accno_id', (SELECT id FROM chart WHERE accno = '5810'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('weightunit', 'lbs');
+INSERT INTO defaults (fldname, fldvalue) VALUES ('precision', '2');
 --
+INSERT INTO curr (rn, curr, precision) VALUES (1,'USD',2);
+INSERT INTO curr (rn, curr, precision) VALUES (2,'CAD',2);
+INSERT INTO curr (rn, curr, precision) VALUES (3,'EUR',2);
+
